@@ -486,7 +486,10 @@ func (e *Editor) GenerateBuildCommand(c *vt100.Canvas, tty *vt100.TTY, filename
 		if matches, err := filepath.Glob(pattern); err == nil && len(matches) != 1 {
 			cmd = exec.Command("odin", "build", ".", "-max-error-count:1")
 		} else {
-			cmd = exec.Command("odin", "build", sourceFilename, "-file", "-build-mode:exe", "-max-error-count:1")
+			cmd = exec.Command("odin", "build", sourceFilename, "-file", "-max-error-count:1")
+		}
+		if e.debugMode {
+			cmd.Args = append(cmd.Args, "-strict-style", "-vet-unused", "-vet-using-stmt", "-vet-using-param", "-vet-style", "-vet-semicolon", "-debug")
 		}
 		cmd.Dir = sourceDir
 		return cmd, everythingIsFine, nil
@@ -534,14 +537,17 @@ func (e *Editor) GenerateBuildCommand(c *vt100.Canvas, tty *vt100.TTY, filename
 // BuildOrExport will try to build the source code or export the document.
 // Returns a status message and then true if an action was performed and another true if compilation/testing worked out.
 // Will also return the executable output file, if available after compilation.
-func (e *Editor) BuildOrExport(c *vt100.Canvas, tty *vt100.TTY, status *StatusBar, filename string, background bool) (string, error) {
+func (e *Editor) BuildOrExport(tty *vt100.TTY, c *vt100.Canvas, status *StatusBar) (string, error) {
+	// Build or export in the background
+	background := e.mode == mode.Markdown
+
 	// Clear the status messages, if we have a status bar
-	if status != nil {
+	if status != nil && c != nil {
 		status.ClearAll(c, false)
 	}
 
 	// Find the absolute path to the source file
-	sourceFilename, err := filepath.Abs(filename)
+	sourceFilename, err := filepath.Abs(e.filename)
 	if err != nil {
 		return "", err
 	}
@@ -752,7 +758,7 @@ func (e *Editor) BuildOrExport(c *vt100.Canvas, tty *vt100.TTY, status *StatusBa
 		errorMessage := "Build error"
 
 		if e.mode == mode.Python {
-			if errorLine, errorColumn, errorMessage := ParsePythonError(string(output), filepath.Base(filename)); errorLine != -1 {
+			if errorLine, errorColumn, errorMessage := ParsePythonError(string(output), filepath.Base(e.filename)); errorLine != -1 {
 				ignoreIndentation := true
 				e.MoveToLineColumnNumber(c, status, errorLine, errorColumn, ignoreIndentation)
 				return "", errors.New(errorMessage)
@@ -1089,7 +1095,7 @@ func (e *Editor) BuildOrExport(c *vt100.Canvas, tty *vt100.TTY, status *StatusBa
 					locationFields := strings.SplitN(line, ":", 3)                  // Already checked for 2 colons in line
 					filenameFields := strings.SplitN(locationFields[0], " --> ", 2) // [0] is fine, already checked for " ---> "
 					errorFilename := strings.TrimSpace(filenameFields[1])           // [1] is fine
-					if filename != errorFilename {
+					if e.filename != errorFilename {
 						return "", errors.New("In " + errorFilename + ": " + errorMessage)
 					}
 					errorY := locationFields[1]
@@ -1303,7 +1309,7 @@ func (e *Editor) Build(c *vt100.Canvas, status *StatusBar, tty *vt100.TTY, alsoR
 
 		// Build or export the current file
 		// The last argument is if the command should run in the background or not
-		outputExecutable, err := e.BuildOrExport(c, tty, status, e.filename, e.mode == mode.Markdown)
+		outputExecutable, err := e.BuildOrExport(tty, c, status)
 		// All clear when it comes to status messages and redrawing
 		status.ClearAll(c, false)
 		if err != nil {
@@ -1336,3 +1342,43 @@ func (e *Editor) Build(c *vt100.Canvas, status *StatusBar, tty *vt100.TTY, alsoR
 
 	}()
 }
+
+// OnlyBuild tries to build/export the given FilenameOrData, without starting a full editor
+func OnlyBuild(fnord FilenameOrData) (string, error) {
+	// Prepare an editor, without tty and canvas
+	e, _, _, err := NewEditor(nil, nil, fnord, 0, 0, NewDefaultTheme(), false, true, false, false, false, false)
+	if err != nil {
+		return "", err
+	}
+	// Prepare a status bar
+	status := e.NewStatusBar(2700*time.Millisecond, "")
+
+	// Try to change directory to where the file is at
+	directory, err := os.Getwd()
+	if err != nil {
+		directory = "."
+	}
+	if !fnord.stdin {
+		directory = filepath.Dir(fnord.filename)
+		_ = os.Chdir(directory)
+	}
+
+	// Build, without tty and canvas
+	if _, err := e.BuildOrExport(nil, nil, status); err != nil {
+		return "", err
+	}
+	// Return a message
+	finalMessage := ""
+	if directory != "." && directory != "" {
+		finalMessage += fmt.Sprintf("cd %s\n", directory) //filepath.Join(filepath.Dir(e.filename), outputExecutable)
+	}
+	if lastCommand, err := readLastCommand(); err == nil { // success
+		finalMessage += lastCommand
+	}
+	if msg := strings.TrimSpace(status.msg); status.isError && msg != "" {
+		return "", errors.New(msg)
+	} else if msg != "" {
+		finalMessage += "\n" + msg
+	}
+	return finalMessage, nil
+}
