@@ -46,7 +46,7 @@ var fileLock = NewLockKeeper(defaultLockFile)
 // a forceFlag for if the file should be force opened
 // If an error and "true" is returned, it is a quit message to the user, and not an error.
 // If an error and "false" is returned, it is an error.
-func Loop(tty *vt100.TTY, fnord FilenameOrData, lineNumber LineNumber, colNumber ColNumber, forceFlag bool, theme Theme, syntaxHighlight, monitorAndReadOnly, nanoMode, createDirectoriesIfMissing, displayQuickHelp bool) (userMessage string, stopParent bool, err error) {
+func Loop(tty *vt100.TTY, fnord FilenameOrData, lineNumber LineNumber, colNumber ColNumber, forceFlag bool, theme Theme, syntaxHighlight, monitorAndReadOnly, nanoMode, createDirectoriesIfMissing, displayQuickHelp, fmtFlag bool) (userMessage string, stopParent, clearOnQuit bool, err error) {
 
 	// Create a Canvas for drawing onto the terminal
 	vt100.Init()
@@ -90,10 +90,13 @@ func Loop(tty *vt100.TTY, fnord FilenameOrData, lineNumber LineNumber, colNumber
 	// New editor struct. Scroll 10 lines at a time, no word wrap.
 	e, messageAfterRedraw, displayedImage, err := NewEditor(tty, c, fnord, lineNumber, colNumber, theme, syntaxHighlight, true, monitorAndReadOnly, nanoMode, createDirectoriesIfMissing, displayQuickHelp)
 	if err != nil {
-		return "", false, err
+		if e != nil {
+			return "", false, e.clearOnQuit, err
+		}
+		return "", false, false, err
 	} else if displayedImage {
 		// A special case for if an image was displayed instead of a file being opened
-		return "", false, nil
+		return "", false, e.clearOnQuit, nil
 	}
 
 	// Find the absolute path to this filename
@@ -143,6 +146,7 @@ func Loop(tty *vt100.TTY, fnord FilenameOrData, lineNumber LineNumber, colNumber
 			quitError(tty, err)
 		}
 	}
+
 	if e.mode == mode.Log && e.readOnly {
 		e.syntaxHighlight = true
 	}
@@ -177,7 +181,7 @@ func Loop(tty *vt100.TTY, fnord FilenameOrData, lineNumber LineNumber, colNumber
 		} else {
 			// Lock the current file, if it's not already locked
 			if err := fileLock.Lock(absFilename); err != nil {
-				return fmt.Sprintf("Locked by another (possibly dead) instance of this editor.\nTry: o -f %s", filepath.Base(absFilename)), false, errors.New(absFilename + " is locked")
+				return fmt.Sprintf("Locked by another (possibly dead) instance of this editor.\nTry: o -f %s", filepath.Base(absFilename)), false, e.clearOnQuit, errors.New(absFilename + " is locked")
 			}
 			// Immediately save the lock file as a signal to other instances of the editor
 			fileLock.Save()
@@ -207,6 +211,20 @@ func Loop(tty *vt100.TTY, fnord FilenameOrData, lineNumber LineNumber, colNumber
 		}()
 	}
 
+	if fmtFlag { // Only try to format the file, save the file and then quit
+		if e.mode == mode.Markdown {
+			e.GoToStartOfTextLine(c)
+			e.FormatAllMarkdownTables()
+		}
+		e.formatCode(c, tty, status, &jsonFormatToggle) // jsonFormatToggle is for also formatting indentation, or not, when formatting
+		if msg := strings.TrimSpace(status.msg); status.isError && msg != "" {
+			quitError(tty, errors.New(msg))
+		}
+		e.UserSave(c, tty, status)
+		// Continue to the loop and then quit
+		e.quit = true
+	}
+
 	// Draw everything once, with slightly different behavior if used over ssh
 	e.InitialRedraw(c, status)
 
@@ -271,8 +289,6 @@ func Loop(tty *vt100.TTY, fnord FilenameOrData, lineNumber LineNumber, colNumber
 			// Clear the search term
 			e.ClearSearch()
 
-			const experimentalFormatMarkdownFeature = true
-
 			// First check if we are editing Markdown and are in a Markdown table (and that this is not the previous thing that we did)
 			if e.mode == mode.Markdown && e.InTable() && !kh.PrevIs("c:23") {
 				e.GoToStartOfTextLine(c)
@@ -281,7 +297,7 @@ func Loop(tty *vt100.TTY, fnord FilenameOrData, lineNumber LineNumber, colNumber
 				const displayQuickHelp = false
 				e.EditMarkdownTable(tty, c, status, bookmark, justFormat, displayQuickHelp)
 				break
-			} else if e.mode == mode.Markdown && !kh.PrevIs("c:23") && experimentalFormatMarkdownFeature {
+			} else if e.mode == mode.Markdown && !kh.PrevIs("c:23") {
 				e.GoToStartOfTextLine(c)
 				e.FormatAllMarkdownTables()
 				break
@@ -396,7 +412,9 @@ func Loop(tty *vt100.TTY, fnord FilenameOrData, lineNumber LineNumber, colNumber
 				if pwd, err := os.Getwd(); err == nil {
 					if absFilename, err := filepath.Abs(e.filename); err == nil { // success
 						e.SetUpSignalHandlers(c, tty, status, true) // only clear signals
-						e.CloseLocksAndLocationHistory(canUseLocks, absFilename, lockTimestamp, forceFlag)
+						var wg sync.WaitGroup
+						e.CloseLocksAndLocationHistory(canUseLocks, absFilename, lockTimestamp, forceFlag, &wg)
+						wg.Wait()
 						quitToMan(tty, pwd, absFilename, c.W(), c.H())
 					}
 				}
@@ -409,7 +427,9 @@ func Loop(tty *vt100.TTY, fnord FilenameOrData, lineNumber LineNumber, colNumber
 				if env.Has("NROFF_FILENAME") {
 					if pwd, err := os.Getwd(); err == nil {
 						e.SetUpSignalHandlers(c, tty, status, true) // only clear signals
-						e.CloseLocksAndLocationHistory(canUseLocks, absFilename, lockTimestamp, forceFlag)
+						var wg sync.WaitGroup
+						e.CloseLocksAndLocationHistory(canUseLocks, absFilename, lockTimestamp, forceFlag, &wg)
+						wg.Wait()
 						quitToNroff(tty, pwd, c.W(), c.H())
 					}
 				}
@@ -827,8 +847,7 @@ func Loop(tty *vt100.TTY, fnord FilenameOrData, lineNumber LineNumber, colNumber
 						break
 					} // e.gdb == nil
 					// Build or export the current file
-					// The last argument is if the command should run in the background or not
-					outputExecutable, err := e.BuildOrExport(c, tty, status, e.filename, e.mode == mode.Markdown)
+					outputExecutable, err := e.BuildOrExport(tty, c, status)
 					// All clear when it comes to status messages and redrawing
 					status.ClearAll(c, false)
 					if err != nil && err != errNoSuitableBuildCommand {
@@ -2233,43 +2252,26 @@ func Loop(tty *vt100.TTY, fnord FilenameOrData, lineNumber LineNumber, colNumber
 
 	} // end of main loop
 
-	e.CloseLocksAndLocationHistory(canUseLocks, absFilename, lockTimestamp, forceFlag)
-
-	// Clear all status bar messages
-	status.ClearAll(c, false)
+	var closeLocksWaitGroup sync.WaitGroup
+	e.CloseLocksAndLocationHistory(canUseLocks, absFilename, lockTimestamp, forceFlag, &closeLocksWaitGroup)
 
 	// Quit everything that has to do with the terminal
 	if e.clearOnQuit {
 		vt100.Clear()
 		vt100.Close()
 	} else {
-		c.HideCursorAndDraw()
-		fmt.Println()
+		// Clear all status bar messages
+		status.ClearAll(c, false)
+		// Redraw
+		c.Draw()
 	}
 
 	// Make sure to enable the cursor again
 	vt100.ShowCursor(true)
 
-	// All done
-	return "", e.stopParentOnQuit, nil
-}
+	// Wait for locks to be closed and location history to be written
+	closeLocksWaitGroup.Wait()
 
-// CloseLocksAndLocationHistory tries to close any active file locks and save the location history
-func (e *Editor) CloseLocksAndLocationHistory(canUseLocks bool, absFilename string, lockTimestamp time.Time, forceFlag bool) {
-	if canUseLocks {
-		// Start by loading the lock overview, just in case something has happened in the mean time
-		fileLock.Load()
-		// Check if the lock is unchanged
-		fileLockTimestamp := fileLock.GetTimestamp(absFilename)
-		lockUnchanged := lockTimestamp == fileLockTimestamp
-		// TODO: If the stored timestamp is older than uptime, unlock and save the lock overview
-		if !forceFlag || lockUnchanged {
-			// If the file has not been locked externally since this instance of the editor was loaded, don't
-			// Unlock the current file and save the lock overview. Ignore errors because they are not critical.
-			fileLock.Unlock(absFilename)
-			fileLock.Save()
-		}
-	}
-	// Save the current location in the location history and write it to file
-	e.SaveLocation(absFilename, locationHistory)
+	// All done
+	return "", e.stopParentOnQuit, e.clearOnQuit, nil
 }
