@@ -6,7 +6,6 @@ import (
 	"io"
 	"os"
 	"path/filepath"
-	"regexp"
 	"sort"
 	"strings"
 	"sync"
@@ -14,6 +13,7 @@ import (
 	"time"
 
 	"github.com/spf13/pflag"
+	"github.com/xyproto/digraph"
 	"github.com/xyproto/env/v2"
 	"github.com/xyproto/files"
 	"github.com/xyproto/ollamaclient/v2"
@@ -22,7 +22,7 @@ import (
 )
 
 const (
-	versionString = "Orbiton 2.68.4"
+	versionString = "Orbiton 2.68.6"
 
 	// How many lines of context above and below should the tab completion try to use?
 	ollamaContextLines = 20
@@ -72,8 +72,10 @@ func main() {
 		ollamaTabCompletion    bool
 		catFlag                bool
 		batFlag                bool
-		fmtFlag                bool
+		formatFlag             bool
 		buildFlag              bool
+		noApproxMatchFlag      bool
+		listDigraphsFlag       bool
 	)
 
 	pflag.BoolVarP(&copyFlag, "copy", "c", false, "copy a file into the clipboard and quit")
@@ -92,8 +94,10 @@ func main() {
 	pflag.BoolVarP(&ollamaTabCompletion, "ollama", "o", env.Bool("ORBITON_OLLAMA"), "use Ollama for tab completion")
 	pflag.BoolVarP(&catFlag, "list", "t", false, "List the file with colors instead of editing it")
 	pflag.BoolVarP(&batFlag, "bat", "B", false, "Cat the file with colors instead of editing it, using bat")
-	pflag.BoolVarP(&fmtFlag, "fmt", "F", false, "Try to build the file instead of editing it")
+	pflag.BoolVarP(&formatFlag, "format", "F", false, "Try to build the file instead of editing it")
 	pflag.BoolVarP(&buildFlag, "build", "b", false, "Try to build the file instead of editing it")
+	pflag.BoolVarP(&noApproxMatchFlag, "noapprox", "x", false, "Disable approximate filename matching")
+	pflag.BoolVarP(&listDigraphsFlag, "digraphs", "g", false, "List digraphs")
 
 	pflag.Parse()
 
@@ -111,22 +115,19 @@ func main() {
 		return
 	}
 
+	if listDigraphsFlag {
+		digraph.PrintTable()
+		return
+	}
+
 	// Output the last used build, export or format command
 	if lastCommandFlag {
-		data, err := os.ReadFile(lastCommandFile)
+		lastCommand, err := readLastCommand()
 		if err != nil {
-			fmt.Println("no available last command")
-			return
-		}
-		// Remove the shebang
-		firstLineAndRest := strings.SplitN(string(data), "\n", 2)
-		if len(firstLineAndRest) != 2 || !strings.HasPrefix(firstLineAndRest[0], "#") {
-			fmt.Fprintf(os.Stderr, "unrecognized contents in %s\n", lastCommandFile)
+			fmt.Fprintln(os.Stderr, err)
 			os.Exit(1)
 		}
-		theRest := strings.TrimSpace(firstLineAndRest[1])
-		replaced := regexp.MustCompile(`/tmp/o\..*$`).ReplaceAllString(theRest, "")
-		fmt.Println(replaced)
+		fmt.Println(lastCommand)
 		return
 	}
 
@@ -167,13 +168,9 @@ func main() {
 		n, headString, tailString, err := WriteClipboardToFile(filename, forceFlag, primaryClipboard)
 		if err != nil {
 			fmt.Fprintf(os.Stderr, "error: %v\n", err)
-			quitMut.Lock()
-			defer quitMut.Unlock()
 			os.Exit(1)
 		} else if n == 0 {
 			fmt.Fprintf(os.Stderr, "Wrote 0 bytes to %s\n", filename)
-			quitMut.Lock()
-			defer quitMut.Unlock()
 			os.Exit(1)
 		}
 		// chmod +x if this looks like a shell script or is in ie. /usr/bin
@@ -202,13 +199,9 @@ func main() {
 		n, tailString, err := SetClipboardFromFile(filename, primaryClipboard)
 		if err != nil {
 			fmt.Fprintf(os.Stderr, "error: %v\n", err)
-			quitMut.Lock()
-			defer quitMut.Unlock()
 			os.Exit(1)
 		} else if n == 0 {
 			fmt.Fprintf(os.Stderr, "Wrote 0 bytes to %s\n", filename)
-			quitMut.Lock()
-			defer quitMut.Unlock()
 			os.Exit(1)
 		}
 		plural := "s"
@@ -265,8 +258,6 @@ func main() {
 			// Start the game
 			if _, err := Game(); err != nil {
 				fmt.Fprintln(os.Stderr, err)
-				quitMut.Lock()
-				defer quitMut.Unlock()
 				os.Exit(1)
 			}
 			return
@@ -281,8 +272,6 @@ func main() {
 				if err := syscall.Exec(visudoPath, []string{"visudo"}, env); err != nil {
 					// Could not exec visudo
 					fmt.Fprintln(os.Stderr, err)
-					quitMut.Lock()
-					defer quitMut.Unlock()
 					os.Exit(1)
 				}
 				// No need to return here, because syscall.Exec replaces the current process
@@ -340,58 +329,66 @@ func main() {
 		fnord.ExpandUser()
 
 		// Check if the given filename is not a file or a symlink
-		if !files.IsFileOrSymlink(fnord.filename) {
-			if strings.HasSuffix(fnord.filename, ".") {
-				// If the filename ends with "." and the file does not exist, assume this was a result of tab-completion going wrong.
-				// If there are multiple files that exist that start with the given filename, open the one first in the alphabet (.cpp before .o)
-				matches, err := filepath.Glob(fnord.filename + "*")
-				if err == nil && len(matches) > 0 { // no error and at least 1 match
-					// Filter out any binary files
-					matches = files.FilterOutBinaryFiles(matches)
-					if len(matches) > 0 {
-						sort.Strings(matches)
-						// If the matches contains low priority suffixes, such as ".lock", then move it last
-						for i, fn := range matches {
-							if hasSuffix(fn, probablyDoesNotWantToEditExtensions) {
-								// Move this filename last
-								matches = append(matches[:i], matches[i+1:]...)
-								matches = append(matches, fn)
-								break
+		if !noApproxMatchFlag {
+			if !files.IsFileOrSymlink(fnord.filename) {
+				if strings.HasSuffix(fnord.filename, ".") {
+					// If the filename ends with "." and the file does not exist, assume this was a result of tab-completion going wrong.
+					// If there are multiple files that exist that start with the given filename, open the one first in the alphabet (.cpp before .o)
+					matches, err := filepath.Glob(fnord.filename + "*")
+					if err == nil && len(matches) > 0 { // no error and at least 1 match
+						// Filter out any binary files
+						matches = files.FilterOutBinaryFiles(matches)
+						if len(matches) > 0 {
+							sort.Strings(matches)
+							// If the matches contains low priority suffixes, such as ".lock", then move it last
+							matchesRegular := make([]string, len(matches))
+							matchesLowPri := make([]string, len(matches))
+							for _, fn := range matches {
+								if !hasSuffix(fn, probablyDoesNotWantToEditExtensions) {
+									matchesRegular = append(matchesRegular, fn)
+								} else {
+									// Store as a low-priority match
+									matchesLowPri = append(matchesLowPri, fn)
+								}
+							}
+							// Combine the regular and the low-priority matches
+							matches = append(matchesRegular, matchesLowPri...)
+							if len(matches) > 0 && len(matches[0]) > 0 {
+								// Use the first filename in the list of matches
+								fnord.filename = matches[0]
 							}
 						}
-						// Use the first filename in the list of matches
-						fnord.filename = matches[0]
+					}
+				} else if !strings.Contains(fnord.filename, ".") && allLower(fnord.filename) {
+					// The filename has no ".", is written in lowercase and it does not exist,
+					// but more than one file that starts with the filename  exists. Assume tab-completion failed.
+					matches, err := filepath.Glob(fnord.filename + "*")
+					if err == nil && len(matches) > 1 { // no error and more than 1 match
+						// Use the first non-binary match of the sorted results
+						matches = files.FilterOutBinaryFiles(matches)
+						if len(matches) > 0 {
+							sort.Strings(matches)
+							fnord.filename = matches[0]
+						}
+					}
+				} else {
+					// Also match ie. "PKGBUILD" if just "Pk" was entered
+					matches, err := filepath.Glob(strings.ToTitle(fnord.filename) + "*")
+					if err == nil && len(matches) >= 1 { // no error and at least 1 match
+						// Use the first non-binary match of the sorted results
+						matches = files.FilterOutBinaryFiles(matches)
+						if len(matches) > 0 {
+							sort.Strings(matches)
+							fnord.filename = matches[0]
+						}
 					}
 				}
-			} else if !strings.Contains(fnord.filename, ".") && allLower(fnord.filename) {
-				// The filename has no ".", is written in lowercase and it does not exist,
-				// but more than one file that starts with the filename  exists. Assume tab-completion failed.
-				matches, err := filepath.Glob(fnord.filename + "*")
-				if err == nil && len(matches) > 1 { // no error and more than 1 match
-					// Use the first non-binary match of the sorted results
-					matches = files.FilterOutBinaryFiles(matches)
-					if len(matches) > 0 {
-						sort.Strings(matches)
-						fnord.filename = matches[0]
-					}
-				}
-			} else {
-				// Also match ie. "PKGBUILD" if just "Pk" was entered
-				matches, err := filepath.Glob(strings.ToTitle(fnord.filename) + "*")
-				if err == nil && len(matches) >= 1 { // no error and at least 1 match
-					// Use the first non-binary match of the sorted results
-					matches = files.FilterOutBinaryFiles(matches)
-					if len(matches) > 0 {
-						sort.Strings(matches)
-						fnord.filename = matches[0]
-					}
-				}
-			}
+			} // !noApproxMatchFlag
 		}
 	}
 
 	// Set the terminal title, if the current terminal emulator supports it, and NO_COLOR is not set
-	fnord.SetTitle()
+	go fnord.SetTitle()
 
 	// If the editor executable has been named "red", use the red/gray theme by default
 	theme := NewDefaultTheme()
@@ -432,6 +429,14 @@ func main() {
 	} else if batFlag { // This should NOT happen if only ORBITON_BAT is set!
 		// List the file in a colorful way, using bat, and quit
 		quitBat(fnord.filename)
+	} else if buildFlag {
+		msg, err := OnlyBuild(fnord)
+		if err != nil {
+			fmt.Fprintln(os.Stderr, err.Error())
+			os.Exit(1)
+		}
+		fmt.Println(msg)
+		os.Exit(0)
 	}
 
 	// Initialize the VT100 terminal
@@ -445,7 +450,7 @@ func main() {
 	defer tty.Close()
 
 	// Run the main editor loop
-	userMessage, stopParent, err := Loop(tty, fnord, lineNumber, colNumber, forceFlag, theme, syntaxHighlight, monitorAndReadOnlyFlag, nanoMode, createDirectoriesFlag, quickHelpFlag)
+	userMessage, stopParent, clearOnQuit, err := Loop(tty, fnord, lineNumber, colNumber, forceFlag, theme, syntaxHighlight, monitorAndReadOnlyFlag, nanoMode, createDirectoriesFlag, quickHelpFlag, formatFlag)
 
 	// SIGQUIT the parent PID. Useful if being opened repeatedly by a find command.
 	if stopParent {
@@ -458,7 +463,11 @@ func main() {
 	NoTitle()
 
 	// Clear the current color attribute
-	fmt.Print(vt100.Stop())
+	if !clearOnQuit {
+		fmt.Print("\n" + vt100.Stop())
+	} else {
+		fmt.Print(vt100.Stop())
+	}
 
 	traceComplete() // if building with -tags trace
 
